==> apache-inlong-1.11.0-src.tar.gz: apache-inlong-1.11.0/inlong-agent/agent-common/src/main/java/org/apache/inlong/agent/plugin/file/Task.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.agent.plugin.file;

import org.apache.inlong.agent.conf.TaskProfile;
import org.apache.inlong.agent.db.Db;
import org.apache.inlong.agent.state.AbstractStateWrapper;

import java.io.IOException;

/**
 * Task interface, which generates instance in condition.
 */
public abstract class Task extends AbstractStateWrapper {

    /**
     * init task by profile
     *
     * @throws IOException
     */
    public abstract void init(Object srcManager, TaskProfile profile, Db basicDb) throws IOException;

    /**
     * destroy task.
     */
    public abstract void destroy();

    /**
     * get task profile
     */
    public abstract TaskProfile getProfile();

    /**
     * get task id
     */
    public abstract String getTaskId();

    /**
     * is profile valid
     */
    public abstract boolean isProfileValid(TaskProfile profile);
}

==> apache-inlong-1.13.0-src.tar.gz: apache-inlong-1.13.0/inlong-agent/agent-common/src/main/java/org/apache/inlong/agent/plugin/file/Task.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.agent.plugin.file;

import org.apache.inlong.agent.conf.TaskProfile;
import org.apache.inlong.agent.state.AbstractStateWrapper;
import org.apache.inlong.agent.store.Store;

import java.io.IOException;

/**
 * Task interface, which generates instance in condition.
 */
public abstract class Task extends AbstractStateWrapper {

    /**
     * init task by profile
     *
     * @throws IOException
     */
    public abstract void init(Object srcManager, TaskProfile profile, Store basicStore) throws IOException;

    /**
     * destroy task.
     */
    public abstract void destroy();

    /**
     * get task profile
     */
    public abstract TaskProfile getProfile();

    /**
     * get task id
     */
    public abstract String getTaskId();

    /**
     * is profile valid
     */
    public abstract boolean isProfileValid(TaskProfile profile);
}
